@@ -55,7 +55,7 @@ void set_style(FL_OBJECT *obj, long arg)
 void br_callback(FL_OBJECT *ob, long arg)
 {
     char buf[1024];
-    char *mb[] = {"","left","middle","right", "button4", "button5"};
+    char *mb[] = {"","left","middle","right"};
     int i, b;
 
     if((b = fl_mouse_button()) < FL_SHORTCUT)
@@ -68,6 +68,39 @@ void br_callback(FL_OBJECT *ob, long arg)
     fl_set_object_label(readout,buf);
 }
 
+void vcallback(FL_OBJECT *ob, int topline, void *data)
+{
+     int i;
+     for ( i = 1; i < 4; i++)
+     {
+         fl_set_browser_topline(br[i], topline);
+     }
+}
+
+
+static void 
+link_browsers(FL_OBJECT *ob, long data)
+{
+    int sync = fl_get_button(ob);
+
+    fl_set_object_label(ob,sync ? "Unlink":"Link");
+
+    if (sync)
+    {
+       fl_set_browser_vscrollbar(br[1], FL_OFF);
+       fl_set_browser_vscrollbar(br[2], FL_OFF);
+       fl_set_browser_vscrollbar(br[3], FL_OFF);
+       fl_set_browser_vscroll_callback(br[0], vcallback,0);
+    }
+    else
+    {
+       fl_set_browser_vscrollbar(br[1], FL_ON);
+       fl_set_browser_vscrollbar(br[2], FL_ON);
+       fl_set_browser_vscrollbar(br[3], FL_ON);
+       fl_set_browser_vscroll_callback(br[0], 0,0);
+    }     
+}
+
 void create_form(void)
 {
   FL_OBJECT *obj;
@@ -109,6 +142,8 @@ void create_form(void)
   obj = fl_add_lightbutton(FL_RADIO_BUTTON,350,500,100,30,"Large");
     fl_set_object_lsize(obj,FL_LARGE_SIZE);
     fl_set_object_callback(obj,set_size,obj->lsize);
+  obj = fl_add_button(FL_BUTTON, 470, 510, 45,30, "Link");
+    fl_set_object_callback(obj, link_browsers, 0);
   fl_end_group();
 
   fl_bgn_group();
@@ -136,7 +171,7 @@ void fill_browsers(void)
    for (i=0; i<4; i++)
       for (j=1; j<=100; j++)
       {
-         if ( j == 5)
+         if ( j == 5 || j==6)
             sprintf(buf,"@NLine with qb %3d",j);
          else if ( j == 10)
             strcpy(buf,"@-trailing text should be ignored");
