@@ -15,30 +15,14 @@ void done_cb(FL_OBJECT *ob, long data)
    exit(0);
 }
 
-int post(FL_OBJECT *ob, int e, int mx, int my, int k, void *x)
-{
-   int cx, cy, pos;
-   char buf[128];
-
-   pos = fl_get_input_cursorpos(ob, &cx,&cy);
-
-   sprintf(buf,"x=%d y=%d",cx, cy);
-/*
-   fl_set_object_label(((FD_input *)ob->form->fdui)->report,buf);
-      fprintf(stderr,"%s\n",buf); */
-     return 0;
-}
-     
-
-
 void input_cb(FL_OBJECT *ob, long data)
 {
-   int cx, cy, pos;
+   int cx, cy;
    char buf[128];
 
-   pos = fl_get_input_cursorpos(ob, &cx,&cy);
+   fl_get_input_cursorpos(ob, &cx,&cy);
    sprintf(buf,"x=%d y=%d",cx, cy);
- /* fl_set_object_label(((FD_input *)ob->form->fdui)->report,buf); */
+   fl_set_object_label(((FD_input *)ob->form->fdui)->report,buf);
 }
 
 void hide_show_cb(FL_OBJECT *ob, long data)
@@ -62,9 +46,7 @@ int main(int argc, char *argv[])
    /* fill-in form initialization code */
    fl_set_object_dblbuffer(fd_input->report,1);
    fl_set_object_return(fd_input->multiinput,FL_RETURN_ALWAYS);
-   fl_set_object_posthandler(fd_input->multiinput, post);
    fl_set_object_return(fd_input->norminput,FL_RETURN_ALWAYS);
-   fl_set_input_fieldchar(fd_input->secretx,'*');
 
    /* show the first form */
    fl_show_form(fd_input->input,FL_PLACE_CENTERFREE,FL_FULLBORDER,"input");
