@@ -20,7 +20,7 @@ int
 main(int argc, char *argv[])
 {
   FL_FORM *form;
-  FL_OBJECT *pos, *button;
+  FL_OBJECT *pos;
 
   fl_initialize(&argc, argv, "FormDemo", 0, 0);
 
@@ -33,7 +33,7 @@ main(int argc, char *argv[])
      yval = fl_add_box(FL_DOWN_BOX,270,90,100,30,"");
      fl_set_object_color(xval,FL_COL1,FL_COL1);
      fl_set_object_color(yval,FL_COL1,FL_COL1);
-     button = fl_add_button(FL_NORMAL_BUTTON,270,210,100,30,"Exit");
+     fl_add_button(FL_NORMAL_BUTTON,270,210,100,30,"Exit");
   fl_end_form();
 
   fl_show_form(form,FL_PLACE_CENTER,FL_NOBORDER,"positioner");
