@@ -1,6 +1,5 @@
-/* 
- * Demo showing secret input fields
- */
+/* Demo showing secret input fields
+*/
 
 #include <stdio.h>
 #include "forms.h"
@@ -16,9 +15,7 @@ main(int argc, char *argv[])
 
   form = fl_bgn_form( FL_UP_BOX,400,300);
     password1 = fl_add_input(FL_SECRET_INPUT,140,40,160,40,"Password 1:");
-    fl_set_input_fieldchar(password1,'x');
     password2 = fl_add_input(FL_SECRET_INPUT,140,100,160,40,"Password 2:");
-    fl_set_input_fieldchar(password2,'y');
     info = fl_add_box(FL_SHADOW_BOX,20,160,360,40,"");
     but = fl_add_button( FL_NORMAL_BUTTON,280,240,100,40,"Quit");
   fl_end_form();
