@@ -8,7 +8,11 @@ CCFLAG=-O2 -fPIC
 LDFLAG=-O2 -s
 AR=ar rs
 RANLIB=touch
-XINCLUDE=--I/usr/X11R6/include
+#XINCLUDE=-I../xpm-3.4k -I/usr/X11R6/include  -I../../jpeg-6b
+#SYSLIB=-L../xpm-3.4k/lib -lXpm -L/usr/X11R6/lib -lX11 -lm
+#JPEG=-L../../jpeg-6b/ -ljpeg
+# uncomment the following three lines before make bdist
+XINCLUDE=-I/usr/X11R6/include 
 SYSLIB=-L/usr/X11R6/lib -lX11 -lm
 JPEG=
 
